'''
REQUIREMENTS

Trello Authentication

Information for finding the Client and Board IDs can be found in the README

You'll need your Trello API credentials and a valid Token
Trello API keys can be found at https://trello.com/app-key
The Token can be generated by clicking `Token` on the same page

Google Sheets Authentication

The URL of the Document and the Workseet name will be needed

Instructions for generating the keyfile can be found at
https://pygsheets.readthedocs.io/en/latest/authorizing.html

Follow the steps, and once the JSON file is downloaded, move it to
~/.trkr/keyfile.json
'''

import os
import configparser

def bolden(message):
  return "\033[1m" + message + "\033[0m"

def main():
  config = configparser.ConfigParser()
  home = os.path.expanduser("~")

  print(__doc__)

  if not os.path.exists(os.path.join(home, ".trkr")):
      os.makedirs(os.path.join(home, ".trkr"))

  config_path = os.path.join(home, ".trkr/config.ini")

  config["default"] = {
    "email": input("Email: ")
  }

  print(f"\n{bolden('Trello Setup')}")

  config["trello"] = {
    "user_id": input("Client ID: "),
    "board_id": input("Board ID: "),
    "api_key": input("API Key: "),
    "api_secret": input("API Secret: "),
    "token": input("Token: ")
  }

  print("\nGoogle Sheets Setup\n")

  config["sheets"] = {
    "url": input("Document URL: "),
    "wks_name": input("Worksheet Name: ")
  }

  print("Generate/ask for a keyfile and move it to ~/.trkr/keyfile.json")
  input("Press ENTER when completed")

  with open(config_path, "w+") as configfile:
    config.write(configfile)
